type MetasrvOptions = GreptimeOptions<MetasrvOptions>;Aliased Type
struct MetasrvOptions {
pub runtime: RuntimeOptions,
pub plugins: Vec<PluginOptions>,
pub component: MetasrvOptions,
}Fields
runtime: RuntimeOptionsThe runtime options.
plugins: Vec<PluginOptions>The plugin options.
Deserialized leniently via deserialize_plugin_options: plugin
options not recognized by the current build are dropped (with a deferred
warning) instead of aborting startup, while malformed payloads for known
variants still error.
component: MetasrvOptionsThe options of each component (like Datanode or Standalone) of GreptimeDB.